# Gaitmap-MAD

This is a companion package to the `gaitmap` library.
It contains algorithms developed by the [MaD Lab](https://www.mad.tf.fau.de/) in collaboration with industry partners.
Compared to the main gaitmap package, this package is published under a AGPL-3.0 license.

To learn more about gaitmap and gaitmap_mad, please visit the 
[gaitmap documentation](https://gaitmap.readthedocs.io/en/latest/) or the [github repository](https://github.com/mad-lab-fau/gaitmap/) 

Note: You should not install this package without gaitmap! Always install the same version of gaitmap and gaitmap_mad.